@@ -1,6 +1,7 @@
 #' @title RequestSignature
 #' @description General purpose request signature builder
 #' @export
+#' @keywords internal
 #' @examples
 #' # make request signature
 #' x <- RequestSignature$new(method = "get", uri = "https:/httpbin.org/get")
@@ -34,7 +35,7 @@
 #' bb$headers
 #' bb$body
 #' bb$to_s()
-#' 
+#'
 #' # with disk path
 #' f <- tempfile()
 #' bb <- RequestSignature$new(
@@ -46,7 +47,7 @@
 #' bb$disk
 #' bb$to_s()
 RequestSignature <- R6::R6Class(
-  'RequestSignature',
+  "RequestSignature",
   public = list(
     #' @field method (character) an http method
     method = NULL,
@@ -64,6 +65,10 @@ RequestSignature <- R6::R6Class(
     url = NULL,
     #' @field disk (character) if writing to disk, the path
     disk = NULL,
+    #' @field fields (various) request body details
+    fields = NULL,
+    #' @field output (various) request output details, disk, memory, etc
+    output = NULL,
 
     #' @description Create a new `RequestSignature` object
     #' @param method the HTTP method (any, head, options, get, post, put,
@@ -83,83 +88,87 @@ RequestSignature <- R6::R6Class(
     #' @param x self
     #' @param ... ignored
     print = function() {
-      cat("<RequestSignature> ", sep = "\n")
-      cat(paste0("  method: ", toupper(self$method)), sep = "\n")
-      cat(paste0("  uri: ", self$uri), sep = "\n")
+      cat_line("<RequestSignature> ")
+      cat_line(paste0("  method: ", toupper(self$method)))
+      cat_line(paste0("  uri: ", self$uri))
       if (!is.null(self$body)) {
-        cat("  body: ", sep = "\n")
+        cat_line("  body: ")
         if (inherits(self$body, "form_file")) {
-          cat(paste0("     ",
-              sprintf("type=%s; path=%s", self$body$type, self$body$path)),
-              sep = "\n")
+          cat_line(paste0(
+            "     ",
+            sprintf("type=%s; path=%s", self$body$type, self$body$path)
+          ))
         } else {
           cat_foo(self$body)
         }
       }
       if (!is.null(self$headers)) {
-        cat("  headers: ", sep = "\n")
+        cat_line("  headers: ")
         cat_foo(self$headers)
       }
       if (!is.null(self$proxies)) {
-        cat("  proxies: ", sep = "\n")
+        cat_line("  proxies: ")
         cat_foo(self$proxies)
       }
       if (!is.null(self$auth)) {
-        cat("  auth: ", sep = "\n")
+        cat_line("  auth: ")
         cat_foo(self$auth)
       }
       if (!is.null(self$disk)) {
-        cat(paste0("  disk: ", self$disk), sep = "\n")
+        cat_line(paste0("  disk: ", self$disk))
+      }
+      if (!is.null(self$fields)) {
+        cat_line("  fields: ")
+        cat_foo(self$fields)
       }
     },
 
     #' @description Request signature to a string
     #' @return a character string representation of the request signature
     to_s = function() {
-      gsub("^\\s+|\\s+$", "", paste(
-        paste0(toupper(self$method), ": "),
-        self$uri,
-        if (!is.null(self$body) && length(self$body)) {
-          paste0(" with body ", to_string(self$body))
-        },
-        if (!is.null(self$headers) && length(self$headers)) {
-          paste0(
-            " with headers ",
-            sprintf("{%s}",
-                    paste(names(self$headers),
-                          unlist(unname(self$headers)), sep = ": ",
-                          collapse = ", "))
-          )
-        }
-      ))
+      gsub(
+        "^\\s+|\\s+$",
+        "",
+        paste(
+          paste0(toupper(self$method), ": "),
+          self$uri,
+          if (!is.null(self$body) && length(self$body)) {
+            paste0(" with body ", to_string(self$body))
+          },
+          if (!is.null(self$headers) && length(self$headers)) {
+            paste0(
+              " with headers ",
+              sprintf(
+                "{%s}",
+                paste(
+                  names(self$headers),
+                  unlist(unname(self$headers)),
+                  sep = ": ",
+                  collapse = ", "
+                )
+              )
+            )
+          }
+        )
+      )
     }
   ),
-
   private = list(
     assign_options = function(options) {
-      if ('body' %in% names(options)) {
-        if (!is.null(options$body) && length(options)) {
-          self$body <- options$body
-        }
-      }
-      if ('headers' %in% names(options)) {
-        if (!is.null(options$headers) && length(options)) {
-          self$headers <- options$headers
-        }
-      }
-      if ('proxies' %in% names(options)) {
-        if (!is.null(options$proxies) && length(options)) {
-          self$proxies <- options$proxies
-        }
-      }
-      if ('auth' %in% names(options)) {
-        if (!is.null(options$auth) && length(options)) {
-          self$auth <- options$auth
-        }
-      }
-      if ('disk' %in% names(options)) {
-        if (!is.null(options$disk) && length(options)) {
-          self$disk <- options$disk
+      op_vars <- c(
+        "body",
+        "headers",
+        "proxies",
+        "auth",
+        "disk",
+        "fields",
+        "output"
+      )
+      for (i in seq_along(op_vars)) {
+        if (op_vars[i] %in% names(options)) {
+          if (!is.null(options[[op_vars[i]]]) && length(options)) {
+            self[[op_vars[i]]] <- options[[op_vars[i]]]
+          }
         }
       }
     }
@@ -167,9 +176,13 @@ RequestSignature <- R6::R6Class(
 )
 
 cat_foo <- function(x) {
-  cat(paste0("     ",
-             paste0(paste(names(x), x, sep = ": "),
-                    collapse = "\n     ")), sep = "\n")
+  cat_line(paste0(
+    "     ",
+    paste0(
+      paste(names(x) %||% "<unnamed>", x, sep = ": "),
+      collapse = "\n     "
+    )
+  ))
 }
 
 to_string <- function(x) {
