@@ -75,6 +75,18 @@ build_crul_request <- function(x) {
   )
 }
 
+crul_mock <- function(on = TRUE) {
+  check_installed("crul")
+  if (on) {
+    options(crul_mock = function(req) {
+      webmockr::CrulAdapter$new()$handle_request(req)
+    })
+  } else {
+    options(crul_mock = NULL)
+  }
+  invisible(on)
+}
+
 #' @rdname Adapter
 #' @export
 #' @keywords internal
@@ -89,29 +101,11 @@ CrulAdapter <- R6::R6Class(
   ),
   private = list(
     pluck_url = function(request) request$url$url,
-    mock = function(on) crul::mock(on),
+    mock = function(on) crul_mock(on),
     build_request = build_crul_request,
     build_response = build_crul_response,
     fetch_request = function(request) {
       private$build_response(request, webmockr_crul_fetch(request))
-    },
-    request_handler = function(request) vcr::RequestHandlerCrul$new(request),
-    update_vcr_disk_path = function(response) {
-      write_disk_path <- vcr::vcr_configuration()$write_disk_path
-
-      # if crul_resp$content is character, it must be a file path (I THINK?)
-      if (is.null(write_disk_path)) {
-        abort(c(
-          "if writing to disk, write_disk_path must be given",
-          "see ?vcr::vcr_configure"
-        ))
-      }
-
-      response$content <- file.path(
-        write_disk_path,
-        basename(response$content)
-      )
-      response
     }
   )
 )
