@@ -1,4 +1,3 @@
-context("remove_request_stub")
 # clear stubs before starting
 stub_registry_clear()
 
@@ -7,16 +6,16 @@ test_that("remove_request_stub", {
   expect_equal(length(stub_registry()$request_stubs), 0)
 
   # make a stub
-  x <- stub_request("get", "https://httpbin.org/get")
+  x <- stub_request("get", hb("/get"))
 
   # no there's a stub
   expect_equal(length(stub_registry()$request_stubs), 1)
 
   # remove the stub
   w <- remove_request_stub(x)
-  expect_is(w, "list")
+  expect_type(w, "list")
   expect_equal(length(w), 0)
-  
+
   # no there's no stubs
   expect_equal(length(stub_registry()$request_stubs), 0)
 })
@@ -27,10 +26,10 @@ test_that("remove_request_stub: removes the stub upon an error", {
   expect_equal(length(stub_registry()$request_stubs), 0)
 
   expect_error(
-    stub_request("post", uri = "https://httpbin.org/post") %>%
+    stub_request("post", uri = hb("/post")) %>%
       to_return(body = 5)
   )
-  expect_equal(length(stub_registry()$request_stubs), 0)  
+  expect_equal(length(stub_registry()$request_stubs), 0)
   stub_registry_clear()
 })
 
